@echo off
rem Batch script to reformat and regroup speedcam.gpx from dowloaded SpeedCamGarmin.zip
rem Used MSXSL.EXE (XSLT processor) could be downloaded from http://www.microsoft.com/download/en/details.aspx?displaylang=en&id=21714


rem Extract downloaded SpeedCamGarmin.zip manually into "SpeedCamGarmin" subfolder or use unzip.exe
rem (unzip.exe could obtained from ftp://ftp.info-zip.org/pub/infozip/win32/unz600xn.exe self-extracting archive)
rem unzip.exe -o SpeedCamGarmin.zip -d SpeedCamGarmin

rem Full/relative path of extracted source GPX file from downloaded SpeedCamGarmin.zip file
set SourceGpxFile=SpeedCamGarmin\POI\speedcam.gpx

rem Source BMP icons folder; could be the extracted SpeedCamGarmin.zip's folder
rem set SourceIconsDir=SpeedCamGarmin\POI
rem set SourceIconsDir=SpeedCam_IconsNew_
if exist SpeedCam_IconsNew_ (set SourceIconsDir=SpeedCam_IconsNew_) else (set SourceIconsDir=SpeedCamGarmin\POI)

rem Source WAV audio files folder (could be an absolute path)
rem Comment this option to exclude audio:
set SourceAudioDir=SpeedCam_Voice

rem Target future GPI name (output folder name; could be an absolute path)
rem set TargetGpxName=mapcam
set TargetGpxName=Speedcam

rem Target GPI root category name (output subfolder name)
set TargetGpxCategory=Mapcam.info Speedcams


rem Customize audio for some alerts
if exist "%SourceAudioDir%\1_60.wav" (set UseSpeedAudioForAlert1=1) else (set UseSpeedAudioForAlert1=0)
if exist "%SourceAudioDir%\5_1.wav" (set UseTypedAudioForAlert5=1) else (set UseTypedAudioForAlert5=0)


echo Creating output directories...
mkdir "%TargetGpxName%"
del /q /s "%TargetGpxName%\*.gpx"
rem for /D %%f in (%TargetGpxName%\*.*) do rmdir /s /q "%%f"
mkdir "%TargetGpxName%\%TargetGpxCategory%"

echo Copying icons into output...
xcopy "%SourceIconsDir%\*.bmp" "%TargetGpxName%" /y

echo Copying audio into output...
if exist "%SourceAudioDir%" xcopy "%SourceAudioDir%\*.wav" "%TargetGpxName%" /y

echo Splitting GPX by groups...
rem Windows FINDSTR utility is used to determine existence of specified alerts type to skip empty .gpx files generation
rem Comment any necessary MSXSL.EXE calling line to exclude appropriate alerts from output:

findstr "\"1\.bmp\"" "%SourceGpxFile%" >NUL
if not errorlevel 1 msxsl.exe "%SourceGpxFile%" GpxFilter.xslt -t -o "%TargetGpxName%\%TargetGpxCategory%\Radar.gpx" WarningTypeId=1 AddSpeedToWarningAudioFileName=%UseSpeedAudioForAlert1%
rem if not errorlevel 1 msxsl.exe "%SourceGpxFile%" GpxFilter.xslt -t -o "%TargetGpxName%\%TargetGpxCategory%\Radar.gpx" WarningTypeId=1 AddSpeedToWarningAudioFileName=0

findstr "\"2\.bmp\"" "%SourceGpxFile%" >NUL
if not errorlevel 1 msxsl.exe "%SourceGpxFile%" GpxFilter.xslt -t -o "%TargetGpxName%\%TargetGpxCategory%\Radar (Traffic Light).gpx" WarningTypeId=2

findstr "\"3\.bmp\"" "%SourceGpxFile%" >NUL
if not errorlevel 1 msxsl.exe "%SourceGpxFile%" GpxFilter.xslt -t -o "%TargetGpxName%\%TargetGpxCategory%\Radar (Red Light).gpx" WarningTypeId=3

findstr "\"4\.bmp\"" "%SourceGpxFile%" >NUL
if not errorlevel 1 msxsl.exe "%SourceGpxFile%" GpxFilter.xslt -t -o "%TargetGpxName%\%TargetGpxCategory%\Radar (Pair).gpx" WarningTypeId=4

findstr "\"5\.bmp\"" "%SourceGpxFile%" >NUL
if not errorlevel 1 msxsl.exe "%SourceGpxFile%" GpxFilter.xslt -t -o "%TargetGpxName%\%TargetGpxCategory%\Mobile Radar.gpx" WarningTypeId=5 AddTypeToWarningAudioFileName=%UseTypedAudioForAlert5%

findstr "\"20\.bmp\"" "%SourceGpxFile%" >NUL
if not errorlevel 1 msxsl.exe "%SourceGpxFile%" GpxFilter.xslt -t -o "%TargetGpxName%\%TargetGpxCategory%\Stationary Post.gpx" WarningTypeId=20

findstr "\"21\.bmp\"" "%SourceGpxFile%" >NUL
if not errorlevel 1 msxsl.exe "%SourceGpxFile%" GpxFilter.xslt -t -o "%TargetGpxName%\%TargetGpxCategory%\Railroad Crossing.gpx" WarningTypeId=21

findstr "\"22\.bmp\"" "%SourceGpxFile%" >NUL
if not errorlevel 1 msxsl.exe "%SourceGpxFile%" GpxFilter.xslt -t -o "%TargetGpxName%\%TargetGpxCategory%\School.gpx" WarningTypeId=22

findstr "\"100\.bmp\"" "%SourceGpxFile%" >NUL
if not errorlevel 1 msxsl.exe "%SourceGpxFile%" GpxFilter.xslt -t -o "%TargetGpxName%\%TargetGpxCategory%\Built-up Area.gpx" WarningTypeId=100

findstr "\"101_[0-9]*\.bmp\"" "%SourceGpxFile%" >NUL
if not errorlevel 1 msxsl.exe "%SourceGpxFile%" GpxFilter.xslt -t -o "%TargetGpxName%\%TargetGpxCategory%\Speed Control.gpx" WarningTypeId=101

findstr "\"102\.bmp\"" "%SourceGpxFile%" >NUL
if not errorlevel 1 msxsl.exe "%SourceGpxFile%" GpxFilter.xslt -t -o "%TargetGpxName%\%TargetGpxCategory%\Speed Bump.gpx" WarningTypeId=102

findstr "\"103\.bmp\"" "%SourceGpxFile%" >NUL
if not errorlevel 1 msxsl.exe "%SourceGpxFile%" GpxFilter.xslt -t -o "%TargetGpxName%\%TargetGpxCategory%\Bad Road.gpx" WarningTypeId=103

findstr "\"104\.bmp\"" "%SourceGpxFile%" >NUL
if not errorlevel 1 msxsl.exe "%SourceGpxFile%" GpxFilter.xslt -t -o "%TargetGpxName%\%TargetGpxCategory%\Dangerous Turn.gpx" WarningTypeId=104

findstr "\"105\.bmp\"" "%SourceGpxFile%" >NUL
if not errorlevel 1 msxsl.exe "%SourceGpxFile%" GpxFilter.xslt -t -o "%TargetGpxName%\%TargetGpxCategory%\Dangerous Crossroad.gpx" WarningTypeId=105

findstr "\"106\.bmp\"" "%SourceGpxFile%" >NUL
if not errorlevel 1 msxsl.exe "%SourceGpxFile%" GpxFilter.xslt -t -o "%TargetGpxName%\%TargetGpxCategory%\Other Danger.gpx" WarningTypeId=106


echo POI Loader can be now called with "%CD%\%TargetGpxName%" folder path to source data files
rem "C:\Program Files\Garmin\POI Loader\POI Loader.exe" /silent

pause
