#!/bin/sh
# Batch script to reformat and regroup speedcam.gpx from dowloaded SpeedCamGarmin.zip
# Used xsltproc (XSLT processor from Libxslt) could be downloaded from http://xmlsoft.org/XSLT/downloads.html


# Extract downloaded SpeedCamGarmin.zip manually into "SpeedCamGarmin" subfolder or use unzip
#unzip -o SpeedCamGarmin.zip -d SpeedCamGarmin

# Full/relative path of extracted source GPX file from downloaded SpeedCamGarmin.zip file
SourceGpxFile=SpeedCamGarmin/POI/speedcam.gpx

# Source BMP icons folder; could be the extracted SpeedCamGarmin.zip's folder
#SourceIconsDir=SpeedCamGarmin/POI
#SourceIconsDir=SpeedCam_IconsNew_
if test -d SpeedCam_IconsNew_; then SourceIconsDir=SpeedCam_IconsNew_; else SourceIconsDir=SpeedCamGarmin/POI; fi

# Source WAV audio files folder (could be an absolute path)
# Comment this option to exclude audio:
SourceAudioDir=SpeedCam_Voice

# Target future GPI name (output folder name; could be an absolute path)
#TargetGpxName=mapcam
TargetGpxName=Speedcam

# Target GPI root category name (output subfolder name)
TargetGpxCategory="Mapcam.info Speedcams"


# Customize audio for some alerts
if test -f "$SourceAudioDir/1_60.wav"; then UseSpeedAudioForAlert1=1; else UseSpeedAudioForAlert1=0; fi
if test -f "$SourceAudioDir/5_1.wav"; then UseTypedAudioForAlert5=1; else UseTypedAudioForAlert5=0; fi


echo "Creating output directories..."
mkdir -p "$TargetGpxName"
rm -f -r "$TargetGpxName"/*.gpx
mkdir -p "$TargetGpxName/$TargetGpxCategory"

echo "Copying icons into output..."
cp -f "$SourceIconsDir"/*.bmp "$TargetGpxName"

echo "Copying audio into output..."
if test -d "$SourceAudioDir"; then cp -f "$SourceAudioDir"/*.wav "$TargetGpxName"; fi

echo "Splitting GPX by groups..."
# Comment any necessary xsltproc calling line to exclude appropriate alerts from output:

if grep -q \"1\.bmp\" "$SourceGpxFile"
then
  xsltproc --param WarningTypeId 1 --param AddSpeedToWarningAudioFileName $UseSpeedAudioForAlert1 GpxFilter.xslt "$SourceGpxFile" > "$TargetGpxName/$TargetGpxCategory/Radar.gpx"
  #xsltproc --param WarningTypeId 1 --param AddSpeedToWarningAudioFileName 0 GpxFilter.xslt "$SourceGpxFile" > "$TargetGpxName/$TargetGpxCategory/Radar.gpx"
fi

if grep -q \"2\.bmp\" "$SourceGpxFile"
then
  xsltproc --param WarningTypeId 2 GpxFilter.xslt "$SourceGpxFile" > "$TargetGpxName/$TargetGpxCategory/Radar (Traffic Light).gpx"
fi

if grep -q \"3\.bmp\" "$SourceGpxFile"
then
  xsltproc --param WarningTypeId 3 GpxFilter.xslt "$SourceGpxFile" > "$TargetGpxName/$TargetGpxCategory/Radar (Red Light).gpx"
fi

if grep -q \"4\.bmp\" "$SourceGpxFile"
then
  xsltproc --param WarningTypeId 4 GpxFilter.xslt "$SourceGpxFile" > "$TargetGpxName/$TargetGpxCategory/Radar (Pair).gpx"
fi

if grep -q \"5\.bmp\" "$SourceGpxFile"
then
  xsltproc --param WarningTypeId 5 --param AddTypeToWarningAudioFileName $UseTypedAudioForAlert5 GpxFilter.xslt "$SourceGpxFile" > "$TargetGpxName/$TargetGpxCategory/Mobile Radar.gpx"
fi

if grep -q \"20\.bmp\" "$SourceGpxFile"
then
  xsltproc --param WarningTypeId 20 GpxFilter.xslt "$SourceGpxFile" > "$TargetGpxName/$TargetGpxCategory/Stationary Post.gpx"
fi

if grep -q \"21\.bmp\" "$SourceGpxFile"
then
  xsltproc --param WarningTypeId 21 GpxFilter.xslt "$SourceGpxFile" > "$TargetGpxName/$TargetGpxCategory/Railroad Crossing.gpx"
fi

if grep -q \"22\.bmp\" "$SourceGpxFile"
then
  xsltproc --param WarningTypeId 22 GpxFilter.xslt "$SourceGpxFile" > "$TargetGpxName/$TargetGpxCategory/School.gpx"
fi

if grep -q \"100\.bmp\" "$SourceGpxFile"
then
  xsltproc --param WarningTypeId 100 GpxFilter.xslt "$SourceGpxFile" > "$TargetGpxName/$TargetGpxCategory/Built-up Area.gpx"
fi

if grep -q \"101_[0-9]*\.bmp\" "$SourceGpxFile"
then
  xsltproc --param WarningTypeId 101 GpxFilter.xslt "$SourceGpxFile" > "$TargetGpxName/$TargetGpxCategory/Speed Control.gpx"
fi

if grep -q \"102\.bmp\" "$SourceGpxFile"
then
  xsltproc --param WarningTypeId 102 GpxFilter.xslt "$SourceGpxFile" > "$TargetGpxName/$TargetGpxCategory/Speed Bump.gpx"
fi

if grep -q \"103\.bmp\" "$SourceGpxFile"
then
  xsltproc --param WarningTypeId 103 GpxFilter.xslt "$SourceGpxFile" > "$TargetGpxName/$TargetGpxCategory/Bad Road.gpx"
fi

if grep -q \"104\.bmp\" "$SourceGpxFile"
then
  xsltproc --param WarningTypeId 104 GpxFilter.xslt "$SourceGpxFile" > "$TargetGpxName/$TargetGpxCategory/Dangerous Turn.gpx"
fi

if grep -q \"105\.bmp\" "$SourceGpxFile"
then
  xsltproc --param WarningTypeId 105 GpxFilter.xslt "$SourceGpxFile" > "$TargetGpxName/$TargetGpxCategory/Dangerous Crossroad.gpx"
fi

if grep -q \"106\.bmp\" "$SourceGpxFile"
then
  xsltproc --param WarningTypeId 106 GpxFilter.xslt "$SourceGpxFile" > "$TargetGpxName/$TargetGpxCategory/Other Danger.gpx"
fi


echo "POI Loader can be now called with '`pwd`/$TargetGpxName' folder path to source data files"
